floor_annotation library
Compatibility entrypoint matching Floor's annotation library filename.
Existing annotation names and semantics are exported unchanged.
Classes
- ColumnInfo
- Allows customization of the column associated with this field.
- Database
- Marks a class as a FloorDatabase.
- DatabaseView
- Marks a class as a database view (a fixed select statement).
- Entity
- Marks a class as a database entity (table).
- ForeignKey
- Declares a foreign key on another Entity.
- Fts3
- Marks an Entity annotated class as an FTS3 entity. This class will have a mapping SQLite FTS3 table in the database.
- Fts4
- Marks an Entity annotated class as an FTS4 entity. This class will have a mapping SQLite FTS4 table in the database.
- FtsTokenizer
- Available option values that can be used with Fts3 & Fts4.
- Index
- Declares an index on an Entity. see: SQLite Index Documentation
- Insert
- Marks a method as an insert method.
- PrimaryKey
- Marks a field in an Entity as the primary key.
- Query
- Marks a method as a query method.
-
TypeConverter<
T, S> - TypeConverters
- Specifies additional type converters that Floor can use. The TypeConverter is added to the scope of the element so if you put it on a class, all methods/fields in that class will be able to use the converter.
- Update
- Marks a method as an update method.
Enums
- ForeignKeyAction
- Constants definition for values that can be used in ForeignKey.onDelete and ForeignKey.onUpdate
- OnConflictStrategy
- Set of conflict handling strategies for insert and update methods.
Constants
- dao → const _Dao
- Marks the class as a Data Access Object.
- delete → const _Delete
- Marks a method as a deletion method.
- entity → const Entity
- Marks a class as a database entity (table).
- fts3 → const Fts3
- Marks an Entity annotated class as an FTS3 entity. This class will have a mapping SQLite FTS3 table in the database.
- fts4 → const Fts4
- Marks an Entity annotated class as an FTS4 entity. This class will have a mapping SQLite FTS4 table in the database.
- ignore → const _Ignore
- Ignores the marked element from Floor's processing logic. It can only be applied to entity's fields.
- insert → const Insert
- Marks a method as an insert method.
- primaryKey → const PrimaryKey
- Marks a field in an Entity as the primary key.
- transaction → const _Transaction
- Marks a method as a transaction method.
- update → const Update
- Marks a method as an update method.